import urllib.request

import appdirs
import platform
import os.path


def cart_url(cart_id):
    return 'http://www.lexaloffle.com/bbs/cposts/{}/{}.p8.png'.format(
        cart_id[0],
        cart_id
    )


def pico8_path():
    if platform.system() == 'Linux':
        return os.path.expanduser("~/.lexaloffle/pico-8")

    return appdirs.user_data_dir('pico-8', False, roaming=True)


def pico8_config_var(key):
    with open(os.path.join(pico8_path(), 'config.txt')) as f:
        for line in f.readlines():
            if line.startswith(key):
                return line.strip()[len(key)+1:]


def cart_path(cart_id):
    return os.path.join(
        pico8_config_var('root_path'),
        '{}.p8.png'.format(cart_id),
    )


def cartretrieve(cart_id):
    url, path = cart_url(cart_id), cart_path(cart_id)
    return urllib.request.urlretrieve(url, path)



import sys

from .downloader import cartretrieve


def main():
    if len(sys.argv) < 2:
        print('need a cart-id as argument! (for example, 10022 gets you Hug Arena)')
        exit(1)

    cart_id = sys.argv[1]
    path, httpmsg = cartretrieve(cart_id)
    print('ok, saved to {}'.format(path))


if __name__ == '__main__':
    main()



from setuptools import setup

PACKAGE_NAME = 'p8dl'
GITHUB_BASE = 'https://github.com/franciscod/'
VERSION = '0.1'
setup(
    name=PACKAGE_NAME,
    packages=[PACKAGE_NAME],
    version=VERSION,
    description='PICO-8 cartridge downloader',
    author='Francisco Demartino',
    author_email='demartino.francisco@gmail.com',
    url=GITHUB_BASE + PACKAGE_NAME,
    download_url=GITHUB_BASE + PACKAGE_NAME + '/tarball/' + VERSION,
    keywords=['pico8', 'pico-8', 'lexaloffle'],
    classifiers=[],
    install_requires=[
        'appdirs',
    ],
    entry_points={
        'console_scripts': [
            'p8dl = p8dl.cli:main'],
    }
)
